;+
; NAME:
;     SXT_RPAXY
; PURPOSE:
;     calculate radii, position angles, and xy's for SXT
; CATEGORY:
;     Yohkoh
; CALLING SEQUENCE:
;     sxt_rpaxy, index, rr, pa, xy
;     sxt_rpaxy, index, rr, pa, xy, center=center
; INPUTS:
;     index of an image
; OPTIONAL (KEYWORD) INPUT PARAMETERS:
;     center, allows input of a coordinate center (default sxt_cen(index))
; OUTPUTS:
;     rr, map of radius values relative to SXT_CEN sun center
;     pa, map of position angles (positive E from N, degrees)
;     xy(dim, dim, 2) maps of x and y values relative to sun center
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; MODIFICATION HISTORY:
;     HSH, written 20-jun-97
;     29-sep-00, added center keyword (HSH)
;-
pro sxt_rpaxy, index, rr, pa, xy, qstop = qstop, center=center
rad = 180/!pi
res = 2^gt_res(index)
dim = 1024/res
cen = sxt_cen(index)/res
if n_elements(center) ne 0 then cen = center
rr = fltarr(dim,dim)
pa = fltarr(dim,dim)
xy = fltarr(dim,dim,2)
radius = get_rb0p(index,/rad)/gt_pix_size(index)
x = findgen(dim)
for i = 0, dim-1 do begin
  xy(*,i,0) = x - cen(0)
  xy(i,*,1) = x - cen(1)
endfor
rr = sqrt(xy(*,*,0)^2+xy(*,*,1)^2) / radius
pa = atan(-xy(*,*,0),xy(*,*,1))*rad
neg = where(pa lt 0)
pa(neg) = pa(neg) + 360
if keyword_set(qstop) then stop
end

